@@ -3,12 +3,17 @@ use Mojo::Base 'App::git::ship';
 
 use Module::CPANfile;
 use Mojo::File qw(path tempfile);
+use Mojo::Util 'decode';
 use POSIX qw(setlocale strftime LC_TIME);
 use Pod::Markdown;
 
 use constant DEBUG => $ENV{GIT_SHIP_DEBUG} || 0;
 
-my $VERSION_RE = qr{\W*\b(\d+\.[\d_]+)\b};
+my $CONTRIB_END_RE        = qr{^=head1};
+my $CONTRIB_NAME_EMAIL_RE = qr{^(\w[\w\s]*\w) - C<(.+)>$};
+my $CONTRIB_NAME_RE       = qr{^(\w[\w\s]*\w)$};
+my $CONTRIB_START_RE      = qr{^=head1 AUTHOR};
+my $VERSION_RE            = qr{\W*\b(\d+\.[\d_]+)\b};
 
 sub build {
   my $self = shift;
@@ -145,6 +150,32 @@ sub _build_config_param_changelog_filename {
   (grep {-w} qw(CHANGELOG.md Changes))[0] || 'Changes';
 }
 
+sub _build_config_param_contributors {
+  my $self = shift;
+  return decode 'UTF-8', $ENV{GIT_SHIP_CONTRIBUTORS} if $ENV{GIT_SHIP_CONTRIBUTORS};
+
+  my @contributors;
+  my $module = decode 'UTF-8', $self->config('main_module_path')->slurp;
+  my $contrib_block;
+  for my $line (split /\n/, $module) {
+    if ($line =~ $CONTRIB_START_RE) {
+      $contrib_block = 1;
+      next;
+    }
+    $contrib_block = 0 if $line =~ $CONTRIB_END_RE;
+    next unless $contrib_block;
+
+    if ($line =~ $CONTRIB_NAME_EMAIL_RE) {
+      push @contributors, "$1 <$2>";
+    }
+    elsif ($line =~ $CONTRIB_NAME_RE) {
+      push @contributors, $1;
+    }
+  }
+
+  return join ',', @contributors;
+}
+
 sub _build_config_param_new_version_format {
   return $ENV{GIT_SHIP_NEW_VERSION_FORMAT} || '%v %Y-%m-%dT%H:%M:%S%z';
 }
@@ -254,6 +285,7 @@ sub _render_makefile_pl {
   $args->{BUILD_REQUIRES} = $r;
   $r                      = $prereqs->requirements_for(qw(test requires))->as_string_hash;
   $args->{TEST_REQUIRES}  = $r;
+  $args->{CONTRIBUTORS}   = [split /,\s*/, $self->config('contributors')];
 
   $self->render_template('Makefile.PL', $args);
   $self->system(qw(perl -c Makefile.PL));    # test Makefile.PL
@@ -276,7 +308,7 @@ sub _render_readme {
     return;
   }
 
-  open my $README, '>', 'README.md' or die "Write README.md: $!";
+  open my $README, '>:encoding(UTF-8)', 'README.md' or die "Write README.md: $!";
   my $parser = Pod::Markdown->new;
   $parser->output_fh($README);
   $parser->parse_string_document($self->config('main_module_path')->slurp);
@@ -663,6 +695,7 @@ Revision history for perl distribution <%= $ship->config('project_name') =~ s!::
  - Started project
 @@ Makefile.PL
 # Generated by git-ship. See 'git-ship --man' for help or https://github.com/jhthorsen/app-git-ship
+use utf8;
 use ExtUtils::MakeMaker;
 my %WriteMakefileArgs = (
   NAME           => '<%= $ship->config('project_name') %>',
@@ -686,6 +719,7 @@ my %WriteMakefileArgs = (
         web  => '<%= $ship->config('homepage') %>',
       },
     },
+    'x_contributors' => <%= $ship->dump($CONTRIBUTORS) %>,
   },
   test => {TESTS => (-e 'META.yml' ? 't/*.t' : 't/*.t xt/*.t')},
 );
